@@ -77,6 +77,9 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         elif arch.startswith('s390'):
             # grub2 support for s390x systems
             self.arch = arch
+        elif arch == 'riscv64':
+            # grub2 support for efi systems
+            self.arch = arch
         else:
             raise KiwiBootLoaderGrubPlatformError(
                 'host architecture %s not supported for grub2 setup' % arch
@@ -101,6 +104,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         self.failsafe_boot = self.failsafe_boot_entry_requested()
         self.mediacheck_boot = self.xml_state.build_type.get_mediacheck()
         self.xen_guest = self.xml_state.is_xen_guest()
+        self.persistency_type = \
+            self.xml_state.build_type.get_devicepersistency()
         self.firmware = FirmWare(
             self.xml_state
         )
@@ -170,7 +175,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 if self.iso_boot:
                     self._create_embedded_fat_efi_image()
 
-    def write_meta_data(self, root_uuid=None, boot_options=''):
+    def write_meta_data(self, root_device=None, boot_options=''):
         """
         Write bootloader setup meta data files
 
@@ -179,17 +184,17 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         * etc/default/zipl2grub.conf.in (s390 only)
         * etc/sysconfig/bootloader
 
-        :param string root_uuid: root device UUID
+        :param string root_device: root device node
         :param string boot_options: kernel options as string
         :param bool iso_boot: indicate target is an ISO
         """
         self.cmdline = ' '.join(
-            [self.get_boot_cmdline(root_uuid), boot_options]
+            [self.get_boot_cmdline(root_device), boot_options]
         )
         self.cmdline_failsafe = ' '.join(
             [self.cmdline, Defaults.get_failsafe_kernel_options(), boot_options]
         )
-        self.root_reference = self._get_root_cmdline_parameter(root_uuid)
+        self.root_reference = self._get_root_cmdline_parameter(root_device)
 
         self._setup_default_grub()
         self._setup_sysconfig_bootloader()
@@ -610,6 +615,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         * GRUB_GFXMODE
         * GRUB_TERMINAL
         * GRUB_DISTRIBUTOR
+        * GRUB_DISABLE_LINUX_UUID
         """
         grub_default_entries = {
             'GRUB_TIMEOUT': self.timeout,
@@ -619,6 +625,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         grub_final_cmdline = re.sub(
             r'root=.* |root=.*$', '', self.cmdline
         ).strip()
+        if self.persistency_type != 'by-uuid':
+            grub_default_entries['GRUB_DISABLE_LINUX_UUID'] = 'true'
         if self.displayname:
             grub_default_entries['GRUB_DISTRIBUTOR'] = '"{0}"'.format(
                 self.displayname
@@ -815,10 +823,25 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             self._create_early_boot_script_for_mbrid_search(
                 early_boot_script, mbrid
             )
+        root_efi_path = '/boot/efi/EFI/BOOT/'
+        root_efi_image = root_efi_path + Defaults.get_efi_image_name(self.arch)
+
+        Path.create(self.root_dir + root_efi_path)
+
         module_list = Defaults.get_grub_efi_modules(multiboot=self.xen_guest)
         module_path = self._get_efi_modules_path(self.root_dir)
         if os.path.exists(module_path + '/linuxefi.mod'):
             module_list.append('linuxefi')
+
+        early_boot_script_on_media = \
+            self.root_dir + root_efi_path + 'earlyboot.cfg'
+        if early_boot_script != early_boot_script_on_media:
+            log.debug(
+                f'Copy earlyboot to media path: {early_boot_script_on_media}'
+            )
+            shutil.copy(
+                early_boot_script, early_boot_script_on_media
+            )
         mkimage_call = Command.run(
             [
                 'chroot', self.root_dir,
@@ -826,19 +849,28 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                     self._get_grub2_mkimage_tool()
                 ) or 'grub2-mkimage',
                 '-O', Defaults.get_efi_module_directory_name(self.arch),
-                '-o', ''.join(
-                    [
-                        '/boot/efi/EFI/BOOT/',
-                        Defaults.get_efi_image_name(self.arch)
-                    ]
-                ),
-                '-c', '/boot/efi/EFI/BOOT/earlyboot.cfg',
+                '-o', root_efi_image,
+                '-c', root_efi_path + 'earlyboot.cfg',
                 '-p', self.get_boot_path() + '/' + self.boot_directory_name,
                 '-d', module_path.replace(self.root_dir, '')
             ] + module_list
         )
         log.debug(mkimage_call.output)
 
+        # Copy generated EFI image to the media directory if this
+        # is different from the system root directory, e.g the case
+        # for live image builds or when using a custom kiwi initrd
+        efi_image_root_file = self.root_dir + root_efi_image
+        efi_image_media_file = os.sep.join(
+            [self.efi_boot_path, os.path.basename(efi_image_root_file)]
+        )
+        if (efi_image_root_file != efi_image_media_file):
+            log.debug(
+                f'Copy grub image to media path: {efi_image_media_file}'
+            )
+            Path.create(os.path.dirname(efi_image_media_file))
+            shutil.copy(efi_image_root_file, efi_image_media_file)
+
     def _create_efi_config_search(self, uuid=None, mbrid=None):
         efi_boot_config = self.efi_boot_path + '/grub.cfg'
         self.early_boot_script_efi = efi_boot_config
@@ -858,11 +890,19 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         self._create_early_boot_script_for_mbrid_search(
             early_boot_script, mbrid
         )
-        shutil.copy(
-            early_boot_script, os.sep.join(
-                [self.root_dir, 'boot', self.boot_directory_name]
-            )
+        early_boot_script_on_media = os.sep.join(
+            [self.root_dir, 'boot', self.boot_directory_name, 'earlyboot.cfg']
         )
+        if early_boot_script != early_boot_script_on_media:
+            log.debug(
+                f'Copy earlyboot to media path: {early_boot_script_on_media}'
+            )
+            Path.create(
+                os.path.dirname(early_boot_script_on_media)
+            )
+            shutil.copy(
+                early_boot_script, early_boot_script_on_media
+            )
         mkimage_call = Command.run(
             [
                 'chroot', self.root_dir,
@@ -880,15 +920,17 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         )
         log.debug(mkimage_call.output)
 
-        # The following copy is needed for images that uses the
-        # custom boot image feature. In this mode the boot image(initrd)
-        # root tree is different from the system root tree
-        # and it's needed to copy the generated grub image there
+        # Copy generated EFI image to the media directory if this
+        # is different from the system root directory, e.g the case
+        # for live image builds or when using a custom kiwi initrd
         bios_image_root_file = self._get_bios_image_name(self.root_dir)
         bios_image_media_file = bios_image_root_file.replace(
             self.root_dir, lookup_path
         )
         if (bios_image_root_file != bios_image_media_file):
+            log.debug(
+                f'Copy grub image to media path: {bios_image_media_file}'
+            )
             Path.create(os.path.dirname(bios_image_media_file))
             shutil.copy(bios_image_root_file, bios_image_media_file)
 
@@ -1195,48 +1237,45 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
 
     def _fix_grub_root_device_reference(self, config_file, boot_options):
         if self.root_reference:
-            if self.root_filesystem_is_overlay or \
-               self.arch.startswith('s390') or \
-               Defaults.is_buildservice_worker():
-                # grub2-mkconfig has no idea how the correct root= setup is
-                # for disk images created with overlayroot enabled or in a
-                # buildservice worker environment. Because of that the mkconfig
-                # tool just finds the raw partition loop device and includes it
-                # which is wrong. In this particular case we have to patch the
-                # written config file and replace the wrong root= reference with
-                # the correct value.
-                with open(config_file) as grub_config_file:
-                    grub_config = grub_config_file.read()
-                    # The following expression matches any of the following
-                    # grub mkconfig root= settings and replaces it with a
-                    # correct value
-                    # 1. root=LOCAL-KIWI-MAPPED-DEVICE
-                    # 2. root=[a-zA-Z]=ANY-LINUX-BY-ID-VALUE
-                    grub_config = re.sub(
-                        r'(root=[a-zA-Z]+=[a-zA-Z0-9:\.-]+)|(root={0})'.format(
-                            boot_options.get('root_device')
-                        ),
-                        '{0}'.format(self.root_reference),
-                        grub_config
-                    )
+            # grub2-mkconfig has no idea how the correct root= setup is
+            # for disk images created with overlayroot enabled or in a
+            # buildservice worker environment. Because of that the mkconfig
+            # tool just finds the raw partition loop device and includes it
+            # which is wrong. In this particular case we have to patch the
+            # written config file and replace the wrong root= reference with
+            # the correct value.
+            with open(config_file) as grub_config_file:
+                grub_config = grub_config_file.read()
+                # The following expression matches any of the following
+                # grub mkconfig root= settings and replaces it with a
+                # correct value
+                # 1. root=LOCAL-KIWI-MAPPED-DEVICE
+                # 2. root=[a-zA-Z]=ANY-LINUX-BY-ID-VALUE
+                grub_config = re.sub(
+                    r'(root=[a-zA-Z]+=[a-zA-Z0-9:\.-]+)|(root={0})'.format(
+                        boot_options.get('root_device')
+                    ),
+                    '{0}'.format(self.root_reference),
+                    grub_config
+                )
 
-                with open(config_file, 'w') as grub_config_file:
-                    grub_config_file.write(grub_config)
+            with open(config_file, 'w') as grub_config_file:
+                grub_config_file.write(grub_config)
 
-                if self.firmware.efi_mode():
-                    vendor_grubenv_file = \
-                        Defaults.get_vendor_grubenv(self.efi_mount.mountpoint)
-                    if vendor_grubenv_file:
-                        with open(vendor_grubenv_file) as vendor_grubenv:
-                            grubenv = vendor_grubenv.read()
-                            grubenv = grubenv.replace(
-                                'root={0}'.format(
-                                    boot_options.get('root_device')
-                                ),
-                                self.root_reference
-                            )
-                        with open(vendor_grubenv_file, 'w') as vendor_grubenv:
-                            vendor_grubenv.write(grubenv)
+            if self.firmware.efi_mode():
+                vendor_grubenv_file = \
+                    Defaults.get_vendor_grubenv(self.efi_mount.mountpoint)
+                if vendor_grubenv_file:
+                    with open(vendor_grubenv_file) as vendor_grubenv:
+                        grubenv = vendor_grubenv.read()
+                        grubenv = grubenv.replace(
+                            'root={0}'.format(
+                                boot_options.get('root_device')
+                            ),
+                            self.root_reference
+                        )
+                    with open(vendor_grubenv_file, 'w') as vendor_grubenv:
+                        vendor_grubenv.write(grubenv)
 
     def _fix_grub_loader_entries_boot_cmdline(self):
         if self.cmdline:
