@@ -19,21 +19,27 @@ import os
 import logging
 import pickle
 from tempfile import NamedTemporaryFile
+from typing import (
+    Dict, List, Optional, Any
+)
 
 # project
 import kiwi.defaults as defaults
 
 from kiwi.defaults import Defaults
+from kiwi.filesystem.base import FileSystemBase
 from kiwi.bootloader.config import BootLoaderConfig
 from kiwi.bootloader.install import BootLoaderInstall
 from kiwi.system.identifier import SystemIdentifier
 from kiwi.boot.image import BootImage
+from kiwi.boot.image.base import BootImageBase
 from kiwi.storage.setup import DiskSetup
 from kiwi.storage.loop_device import LoopDevice
 from kiwi.firmware import FirmWare
 from kiwi.storage.disk import Disk
 from kiwi.storage.raid_device import RaidDevice
 from kiwi.storage.luks_device import LuksDevice
+from kiwi.storage.device_provider import DeviceProvider
 from kiwi.filesystem import FileSystem
 from kiwi.filesystem.squashfs import FileSystemSquashFs
 from kiwi.volume_manager import VolumeManager
@@ -48,6 +54,7 @@ from kiwi.utils.fstab import Fstab
 from kiwi.path import Path
 from kiwi.runtime_config import RuntimeConfig
 from kiwi.partitioner import Partitioner
+from kiwi.xml_state import XMLState
 
 from kiwi.exceptions import (
     KiwiDiskBootImageError,
@@ -69,8 +76,10 @@ class DiskBuilder:
         * signing_keys: list of package signing keys
         * xz_options: string of XZ compression parameters
     """
-
-    def __init__(self, xml_state, target_dir, root_dir, custom_args=None):
+    def __init__(
+        self, xml_state: XMLState, target_dir: str,
+        root_dir: str, custom_args: Dict = None
+    ):
         self.arch = Defaults.get_platform_name()
         self.root_dir = root_dir
         self.target_dir = target_dir
@@ -147,26 +156,26 @@ class DiskBuilder:
         # an instance of a class with the sync_data capability
         # representing the entire image system except for the boot/ area
         # which could live on another part of the disk
-        self.system = None
+        self.system: Any = None
 
         # an instance of a class with the sync_data capability
         # representing the boot/ area of the disk if not part of
         # self.system
-        self.system_boot = None
+        self.system_boot: Optional[FileSystemBase] = None
 
         # an instance of a class with the sync_data capability
         # representing the boot/efi area of the disk
-        self.system_efi = None
+        self.system_efi: Optional[FileSystemBase] = None
 
         # an instance of a class with the sync_data capability
         # representing the spare_part_mountpoint area of the disk
-        self.system_spare = None
+        self.system_spare: Optional[FileSystemBase] = None
 
         # result store
         self.result = Result(xml_state)
         self.runtime_config = RuntimeConfig()
 
-    def create(self):
+    def create(self) -> Result:
         """
         Build a bootable disk image and optional installation image
         The installation image is a bootable hybrid ISO image which
@@ -203,7 +212,7 @@ class DiskBuilder:
 
         return result
 
-    def create_disk(self):
+    def create_disk(self) -> Result:
         """
         Build a bootable raw disk image
 
@@ -321,7 +330,8 @@ class DiskBuilder:
                 'root_is_snapshot':
                     self.xml_state.build_type.get_btrfs_root_is_snapshot(),
                 'root_is_readonly_snapshot':
-                    self.xml_state.build_type.get_btrfs_root_is_readonly_snapshot(),
+                    self.xml_state.build_type.
+                    get_btrfs_root_is_readonly_snapshot(),
                 'quota_groups':
                     self.xml_state.build_type.get_btrfs_quota_groups(),
                 'resize_on_boot':
@@ -498,7 +508,7 @@ class DiskBuilder:
 
         return self.result
 
-    def create_disk_format(self, result_instance):
+    def create_disk_format(self, result_instance: Result) -> Result:
         """
         Create a bootable disk format from a previously
         created raw disk image
@@ -520,7 +530,7 @@ class DiskBuilder:
 
         return result_instance
 
-    def append_unpartitioned_space(self):
+    def append_unpartitioned_space(self) -> None:
         """
         Extends the raw disk if an unpartitioned area is specified
         """
@@ -541,7 +551,7 @@ class DiskBuilder:
             )
             partitioner.resize_table()
 
-    def create_install_media(self, result_instance):
+    def create_install_media(self, result_instance: Result) -> Result:
         """
         Build an installation image. The installation image is a
         bootable hybrid ISO image which embeds the raw disk image
@@ -583,7 +593,7 @@ class DiskBuilder:
 
         return result_instance
 
-    def _load_boot_image_instance(self):
+    def _load_boot_image_instance(self) -> BootImageBase:
         boot_image_dump_file = self.target_dir + '/boot_image.pickledump'
         if not os.path.exists(boot_image_dump_file):
             raise KiwiInstallMediaError(
@@ -599,19 +609,22 @@ class DiskBuilder:
             )
         return boot_image
 
-    def _setup_selinux_file_contexts(self):
+    def _setup_selinux_file_contexts(self) -> None:
         security_context = '/etc/selinux/targeted/contexts/files/file_contexts'
         if os.path.exists(self.root_dir + security_context):
             self.system_setup.set_selinux_file_contexts(
                 security_context
             )
 
-    def _install_image_requested(self):
-        if self.install_iso or self.install_stick or self.install_pxe:
-            return True
+    def _install_image_requested(self) -> bool:
+        return bool(
+            self.install_iso or self.install_stick or self.install_pxe
+        )
 
-    def _get_exclude_list_for_root_data_sync(self, device_map):
-        exclude_list = Defaults.get_exclude_list_for_root_data_sync()
+    def _get_exclude_list_for_root_data_sync(self, device_map: Dict) -> list:
+        exclude_list = Defaults.\
+            get_exclude_list_for_root_data_sync() + Defaults.\
+            get_exclude_list_from_custom_exclude_files(self.root_dir)
         if 'spare' in device_map and self.spare_part_mountpoint:
             exclude_list.append(
                 '{0}/*'.format(self.spare_part_mountpoint.lstrip(os.sep))
@@ -630,10 +643,11 @@ class DiskBuilder:
             exclude_list.append('boot/efi/.*')
         return exclude_list
 
-    def _get_exclude_list_for_boot_data_sync(self):
+    @staticmethod
+    def _get_exclude_list_for_boot_data_sync() -> list:
         return ['efi/*']
 
-    def _build_spare_filesystem(self, device_map):
+    def _build_spare_filesystem(self, device_map: Dict) -> None:
         if 'spare' in device_map and self.spare_part_fs:
             spare_part_data_path = None
             spare_part_custom_parameters = {
@@ -655,7 +669,7 @@ class DiskBuilder:
             )
             self.system_spare = filesystem
 
-    def _build_boot_filesystems(self, device_map):
+    def _build_boot_filesystems(self, device_map: Dict) -> None:
         if 'efi' in device_map:
             log.info(
                 'Creating EFI(fat16) filesystem on %s',
@@ -688,7 +702,7 @@ class DiskBuilder:
             )
             self.system_boot = filesystem
 
-    def _build_and_map_disk_partitions(self, disksize_mbytes):
+    def _build_and_map_disk_partitions(self, disksize_mbytes: float) -> Dict:
         self.disk.wipe()
         disksize_used_mbytes = 0
         if self.firmware.legacy_bios_mode():
@@ -724,24 +738,25 @@ class DiskBuilder:
             disksize_used_mbytes += partition_mbsize
 
         if self.swap_mbytes:
-            if not self.volume_manager_name or self.volume_manager_name != 'lvm':
+            if not self.volume_manager_name or \
+               self.volume_manager_name != 'lvm':
                 log.info('--> creating SWAP partition')
                 self.disk.create_swap_partition(
-                    self.swap_mbytes
+                    f'{self.swap_mbytes}'
                 )
                 disksize_used_mbytes += self.swap_mbytes
 
         if self.spare_part_mbsize and not self.spare_part_is_last:
             log.info('--> creating spare partition')
             self.disk.create_spare_partition(
-                self.spare_part_mbsize
+                f'{self.spare_part_mbsize}'
             )
 
         if self.root_filesystem_is_overlay:
             log.info('--> creating readonly root partition')
             squashed_root_file = NamedTemporaryFile()
             squashed_root = FileSystemSquashFs(
-                device_provider=None, root_dir=self.root_dir,
+                device_provider=DeviceProvider(), root_dir=self.root_dir,
                 custom_args={
                     'compression':
                         self.xml_state.build_type.get_squashfscompression()
@@ -803,7 +818,7 @@ class DiskBuilder:
 
         return self.disk.get_device()
 
-    def _write_partition_id_config_to_boot_image(self):
+    def _write_partition_id_config_to_boot_image(self) -> None:
         log.info('Creating config.partids in boot system')
         filename = ''.join(
             [self.boot_image.boot_root_directory, '/config.partids']
@@ -818,7 +833,7 @@ class DiskBuilder:
             os.sep + os.path.basename(filename)
         )
 
-    def _write_raid_config_to_boot_image(self):
+    def _write_raid_config_to_boot_image(self) -> None:
         if self.mdraid:
             log.info('Creating etc/mdadm.conf in boot system')
             filename = ''.join(
@@ -829,7 +844,7 @@ class DiskBuilder:
                 os.sep + os.sep.join(['etc', os.path.basename(filename)])
             )
 
-    def _write_crypttab_to_system_image(self):
+    def _write_crypttab_to_system_image(self) -> None:
         if self.luks:
             log.info('Creating etc/crypttab')
             filename = ''.join(
@@ -840,28 +855,30 @@ class DiskBuilder:
                 os.sep + os.sep.join(['etc', os.path.basename(filename)])
             )
 
-    def _write_generic_fstab_to_system_image(self, device_map):
+    def _write_generic_fstab_to_system_image(self, device_map: Dict) -> None:
         log.info('Creating generic system etc/fstab')
         self._write_generic_fstab(device_map, self.system_setup)
 
-    def _write_generic_fstab_to_boot_image(self, device_map):
+    def _write_generic_fstab_to_boot_image(self, device_map: Dict) -> None:
         if self.initrd_system == 'kiwi':
             log.info('Creating generic boot image etc/fstab')
             self._write_generic_fstab(device_map, self.boot_image.setup)
 
-    def _write_generic_fstab(self, device_map, setup):
+    def _write_generic_fstab(
+        self, device_map: Dict, setup: SystemSetup
+    ) -> None:
         root_is_snapshot = \
             self.xml_state.build_type.get_btrfs_root_is_snapshot()
         root_is_readonly_snapshot = \
             self.xml_state.build_type.get_btrfs_root_is_readonly_snapshot()
 
-        fs_check_interval = '1 1'
+        fs_check_interval = '0 1'
         custom_root_mount_args = list(self.custom_root_mount_args)
         if root_is_snapshot and root_is_readonly_snapshot:
             custom_root_mount_args += ['ro']
             fs_check_interval = '0 0'
 
-        self._add_generic_fstab_entry(
+        self._add_fstab_entry(
             device_map['root'].get_device(), '/',
             custom_root_mount_args, fs_check_interval
         )
@@ -870,11 +887,11 @@ class DiskBuilder:
                 boot_mount_point = '/boot/zipl'
             else:
                 boot_mount_point = '/boot'
-            self._add_generic_fstab_entry(
+            self._add_fstab_entry(
                 device_map['boot'].get_device(), boot_mount_point
             )
         if device_map.get('efi'):
-            self._add_generic_fstab_entry(
+            self._add_fstab_entry(
                 device_map['efi'].get_device(), '/boot/efi'
             )
         if self.volume_manager_name:
@@ -885,51 +902,45 @@ class DiskBuilder:
                 self.fstab.add_entry(volume_fstab_entry)
         if device_map.get('spare') and \
            self.spare_part_fs and self.spare_part_mountpoint:
-            self._add_generic_fstab_entry(
+            self._add_fstab_entry(
                 device_map['spare'].get_device(), self.spare_part_mountpoint
             )
         if device_map.get('swap'):
-            if self.volume_manager_name and self.volume_manager_name == 'lvm':
-                self._add_simple_fstab_entry(
-                    device_map['swap'].get_device(), 'swap', 'swap'
-                )
-            else:
-                self._add_generic_fstab_entry(
-                    device_map['swap'].get_device(), 'swap'
-                )
+            self._add_fstab_entry(
+                device_map['swap'].get_device(), 'swap'
+            )
         setup.create_fstab(
             self.fstab
         )
 
-    def _add_simple_fstab_entry(
-        self, device, mount_point, filesystem, options=None, check='0 0'
-    ):
-        if not options:
-            options = ['defaults']
-        fstab_entry = ' '.join(
-            [
-                device, mount_point, filesystem, ','.join(options), check
-            ]
-        )
-        self.fstab.add_entry(fstab_entry)
-
-    def _add_generic_fstab_entry(
-        self, device, mount_point, options=None, check='0 0'
-    ):
+    def _add_fstab_entry(
+        self, device: str, mount_point: str,
+        options: List = None, check: str = '0 0'
+    ) -> None:
         if not options:
             options = ['defaults']
         block_operation = BlockID(device)
-        blkid_type = 'LABEL' if self.persistency_type == 'by-label' else 'UUID'
-        device_id = block_operation.get_blkid(blkid_type)
-        fstab_entry = ' '.join(
-            [
-                blkid_type + '=' + device_id, mount_point,
-                block_operation.get_filesystem(), ','.join(options), check
-            ]
-        )
+        if self.volume_manager_name and self.volume_manager_name == 'lvm' \
+           and mount_point == '/':
+            fstab_entry = ' '.join(
+                [
+                    device, mount_point,
+                    block_operation.get_filesystem(), ','.join(options), check
+                ]
+            )
+        else:
+            blkid_type = 'LABEL' if self.persistency_type == 'by-label' \
+                else 'UUID'
+            device_id = block_operation.get_blkid(blkid_type)
+            fstab_entry = ' '.join(
+                [
+                    blkid_type + '=' + device_id, mount_point,
+                    block_operation.get_filesystem(), ','.join(options), check
+                ]
+            )
         self.fstab.add_entry(fstab_entry)
 
-    def _preserve_root_partition_uuid(self, device_map):
+    def _preserve_root_partition_uuid(self, device_map: Dict) -> None:
         block_operation = BlockID(
             device_map['root'].get_device()
         )
@@ -939,7 +950,7 @@ class DiskBuilder:
                 partition_uuid
             )
 
-    def _preserve_root_filesystem_uuid(self, device_map):
+    def _preserve_root_filesystem_uuid(self, device_map: Dict) -> None:
         block_operation = BlockID(
             device_map['root'].get_device()
         )
@@ -949,13 +960,13 @@ class DiskBuilder:
                 rootfs_uuid
             )
 
-    def _write_image_identifier_to_system_image(self):
+    def _write_image_identifier_to_system_image(self) -> None:
         log.info('Creating image identifier: %s', self.mbrid.get_id())
         self.mbrid.write(
             self.root_dir + '/boot/mbrid'
         )
 
-    def _write_recovery_metadata_to_boot_image(self):
+    def _write_recovery_metadata_to_boot_image(self) -> None:
         if os.path.exists(self.root_dir + '/recovery.partition.size'):
             log.info('Copying recovery metadata to boot image')
             recovery_metadata = ''.join(
@@ -968,7 +979,9 @@ class DiskBuilder:
                 os.sep + os.path.basename(recovery_metadata)
             )
 
-    def _write_bootloader_meta_data_to_system_image(self, device_map):
+    def _write_bootloader_meta_data_to_system_image(
+        self, device_map: Dict
+    ) -> None:
         if self.bootloader != 'custom':
             log.info('Creating %s bootloader configuration', self.bootloader)
             boot_options = []
@@ -979,9 +992,6 @@ class DiskBuilder:
             if 'boot' in device_map:
                 boot_device = device_map['boot']
 
-            root_uuid = self.disk.get_uuid(
-                device_map['root'].get_device()
-            )
             boot_uuid = self.disk.get_uuid(
                 boot_device.get_device()
             )
@@ -992,7 +1002,8 @@ class DiskBuilder:
                 boot_uuid_unmapped
             )
             self.bootloader_config.write_meta_data(
-                root_uuid=root_uuid, boot_options=' '.join(boot_options)
+                root_device=device_map['root'].get_device(),
+                boot_options=' '.join(boot_options)
             )
 
             log.info('Creating config.bootoptions')
@@ -1001,11 +1012,13 @@ class DiskBuilder:
             )
             kexec_boot_options = ' '.join(
                 [
-                    self.bootloader_config.get_boot_cmdline(root_uuid)
+                    self.bootloader_config.get_boot_cmdline(
+                        device_map['root'].get_device()
+                    )
                 ] + boot_options
             )
-            with open(filename, 'w') as boot_options:
-                boot_options.write(
+            with open(filename, 'w') as boot_optionsfp:
+                boot_optionsfp.write(
                     '{0}{1}'.format(kexec_boot_options, os.linesep)
                 )
 
@@ -1015,10 +1028,10 @@ class DiskBuilder:
             boot_partition_id = partition_id_map['kiwi_BootPart']
 
         self.system_setup.call_edit_boot_config_script(
-            self.requested_filesystem, boot_partition_id
+            self.requested_filesystem, int(boot_partition_id)
         )
 
-    def _sync_system_to_image(self, device_map):
+    def _sync_system_to_image(self, device_map: Dict) -> None:
         log.info('Syncing system to image')
         if self.system_spare:
             self.system_spare.sync_data()
@@ -1037,7 +1050,7 @@ class DiskBuilder:
         if self.root_filesystem_is_overlay:
             squashed_root_file = NamedTemporaryFile()
             squashed_root = FileSystemSquashFs(
-                device_provider=None, root_dir=self.root_dir,
+                device_provider=DeviceProvider(), root_dir=self.root_dir,
                 custom_args={
                     'compression':
                         self.xml_state.build_type.get_squashfscompression()
@@ -1059,7 +1072,7 @@ class DiskBuilder:
                 self._get_exclude_list_for_root_data_sync(device_map)
             )
 
-    def _install_bootloader(self, device_map):
+    def _install_bootloader(self, device_map: Dict) -> None:
         root_device = device_map['root']
         boot_device = root_device
         if 'boot' in device_map:
@@ -1114,12 +1127,13 @@ class DiskBuilder:
             )
             if bootloader.install_required():
                 bootloader.install()
+            bootloader.secure_boot_install()
 
         self.system_setup.call_edit_boot_install_script(
             self.diskname, boot_device.get_device()
         )
 
-    def _setup_property_root_is_readonly_snapshot(self):
+    def _setup_property_root_is_readonly_snapshot(self) -> None:
         if self.volume_manager_name:
             root_is_snapshot = \
                 self.xml_state.build_type.get_btrfs_root_is_snapshot()
@@ -1133,7 +1147,7 @@ class DiskBuilder:
                 self.system.set_property_readonly_root()
                 self.system.umount_volumes()
 
-    def _copy_first_boot_files_to_system_image(self):
+    def _copy_first_boot_files_to_system_image(self) -> None:
         boot_names = self.boot_image.get_boot_names()
         if self.initrd_system == 'kiwi':
             log.info('Copy boot files to system image')
