@@ -15,11 +15,14 @@
 # You should have received a copy of the GNU General Public License
 # along with kiwi.  If not, see <http://www.gnu.org/licenses/>
 #
+import logging
 import os
 import glob
 from collections import namedtuple
 import platform
+import yaml
 from pkg_resources import resource_filename
+from typing import List
 
 # project
 from kiwi.path import Path
@@ -32,6 +35,7 @@ from kiwi.exceptions import KiwiBootLoaderGrubDataError
 
 # Default module variables
 POST_DISK_SYNC_SCRIPT = 'disk.sh'
+POST_BOOTSTRAP_SCRIPT = 'post_bootstrap.sh'
 POST_PREPARE_SCRIPT = 'config.sh'
 PRE_CREATE_SCRIPT = 'images.sh'
 EDIT_BOOT_CONFIG_SCRIPT = 'edit_boot_config.sh'
@@ -39,6 +43,10 @@ EDIT_BOOT_INSTALL_SCRIPT = 'edit_boot_install.sh'
 IMAGE_METADATA_DIR = 'image'
 ROOT_VOLUME_NAME = 'LVRoot'
 SHARED_CACHE_DIR = '/var/cache/kiwi'
+CUSTOM_RUNTIME_CONFIG_FILE = None
+PLATFORM_MACHINE = platform.machine()
+
+log = logging.getLogger('kiwi')
 
 
 class Defaults:
@@ -106,11 +114,32 @@ class Defaults:
 
     @staticmethod
     def get_platform_name():
-        arch = platform.machine()
+        """
+        Provides the machine architecture name as used by KIWI
+
+        This is the architecture name as it is returned by 'uname -m'
+        with one exception for the 32bit x86 architecture which is
+        handled as 'ix86' in general
+
+        :return: architecture name
+
+        :rtype: str
+        """
+        arch = PLATFORM_MACHINE
         if arch == 'i686' or arch == 'i586':
             arch = 'ix86'
         return arch
 
+    @staticmethod
+    def set_platform_name(name: str):
+        """
+        Sets the platform architecture once
+
+        :param str name: an architecture name
+        """
+        global PLATFORM_MACHINE
+        PLATFORM_MACHINE = name
+
     @staticmethod
     def is_x86_arch(arch):
         """
@@ -169,6 +198,18 @@ class Defaults:
         """
         return 'http://download.opensuse.org/repositories'
 
+    @staticmethod
+    def get_obs_api_server_url():
+        """
+        Provides the default API server url to access the
+        public open buildservice API
+
+        :return: url path
+
+        :rtype: str
+        """
+        return 'https://api.opensuse.org'
+
     @staticmethod
     def get_solvable_location():
         """
@@ -192,6 +233,16 @@ class Defaults:
         global SHARED_CACHE_DIR
         SHARED_CACHE_DIR = location
 
+    @staticmethod
+    def set_custom_runtime_config_file(filename):
+        """
+        Sets the runtime config file once
+
+        :param str filename: a file path name
+        """
+        global CUSTOM_RUNTIME_CONFIG_FILE
+        CUSTOM_RUNTIME_CONFIG_FILE = filename
+
     @staticmethod
     def get_shared_cache_location():
         """
@@ -234,12 +285,43 @@ class Defaults:
         :rtype: list
         """
         exclude_list = [
-            'image', '.profile', '.kconfig',
+            'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
             Defaults.get_buildservice_env_name(),
             Defaults.get_shared_cache_location()
         ]
         return exclude_list
 
+    @staticmethod
+    def get_exclude_list_from_custom_exclude_files(root_dir: str) -> List:
+        """
+        Provides the list of folders that are excluded by the
+        optional metadata file image/exclude_files.yaml
+
+        :return: list of file and directory names
+
+        :param string root_dir: image root directory
+
+        :rtype: list
+        """
+        exclude_file = os.sep.join(
+            [root_dir, 'image', 'exclude_files.yaml']
+        )
+        exclude_list = []
+        if os.path.isfile(exclude_file):
+            with open(exclude_file) as exclude:
+                exclude_dict = yaml.safe_load(exclude)
+                exclude_data = exclude_dict.get('exclude')
+                if exclude_data and isinstance(exclude_data, list):
+                    for exclude_file in exclude_data:
+                        exclude_list.append(
+                            exclude_file.lstrip(os.sep)
+                        )
+                else:
+                    log.warning(
+                        f'invalid yaml structure in {exclude_file}, ignored'
+                    )
+        return exclude_list
+
     @staticmethod
     def get_exclude_list_for_non_physical_devices():
         """
@@ -967,6 +1049,7 @@ class Defaults:
             'ppc': ['ofw'],
             'ppc64': ['ofw', 'opal'],
             'ppc64le': ['ofw', 'opal'],
+            'riscv64': ['efi', 'uefi'],
             's390': [],
             's390x': []
         }
@@ -996,7 +1079,8 @@ class Defaults:
             'armv6hl': 'efi',
             'armv6l': 'efi',
             'armv7hl': 'efi',
-            'armv7l': 'efi'
+            'armv7l': 'efi',
+            'riscv64': 'efi'
         }
         if arch in default_firmware:
             return default_firmware[arch]
@@ -1052,7 +1136,8 @@ class Defaults:
             'armv5el': 'arm-efi',
             'armv5tel': 'arm-efi',
             'armv6l': 'arm-efi',
-            'armv7l': 'arm-efi'
+            'armv7l': 'arm-efi',
+            'riscv64': 'riscv64-efi'
         }
         if arch in default_module_directory_names:
             return default_module_directory_names[arch]
@@ -1086,7 +1171,8 @@ class Defaults:
             'armv5el': 'bootarm.efi',
             'armv5tel': 'bootarm.efi',
             'armv6l': 'bootarm.efi',
-            'armv7l': 'bootarm.efi'
+            'armv7l': 'bootarm.efi',
+            'riscv64': 'bootriscv64.efi'
         }
         if arch in default_efi_image_names:
             return default_efi_image_names[arch]
@@ -1558,8 +1644,8 @@ class Defaults:
 
         :rtype: str
         """
-        rpm_based = ['zypper', 'yum', 'dnf', 'microdnf']
-        deb_based = ['apt-get']
+        rpm_based = ['zypper', 'dnf', 'microdnf']
+        deb_based = ['apt']
         if package_manager in rpm_based:
             return 'rpm'
         elif package_manager in deb_based:
