@@ -195,6 +195,12 @@ class KiwiConfigFileNotFound(KiwiError):
     """
 
 
+class KiwiConfigFileFormatNotSupported(KiwiError):
+    """
+    Exception raised if kiwi description file format is not supported.
+    """
+
+
 class KiwiContainerSetupError(KiwiError):
     """
     Exception raised if an error in the creation of the
@@ -564,6 +570,13 @@ class KiwiRpmDirNotRemoteError(KiwiError):
     """
 
 
+class KiwiRuntimeConfigFileError(KiwiError):
+    """
+    Exception raised if the provided custom runtime config
+    file could not be found
+    """
+
+
 class KiwiRuntimeConfigFormatError(KiwiError):
     """
     Exception raised if the expected format in the yaml KIWI
