@@ -18,12 +18,16 @@
 import os
 import logging
 import copy
+from typing import (
+    Dict, List, Optional
+)
 
 # project
 from kiwi.defaults import Defaults
 from kiwi.utils.sync import DataSync
 from kiwi.mount_manager import MountManager
 from kiwi.command import Command
+from kiwi.storage.device_provider import DeviceProvider
 
 from kiwi.exceptions import (
     KiwiFileSystemSyncError
@@ -43,12 +47,15 @@ class FileSystemBase:
     :param string root_dir: root directory path name
     :param dict custom_args: custom filesystem arguments
     """
-    def __init__(self, device_provider, root_dir=None, custom_args=None):
+    def __init__(
+        self, device_provider: DeviceProvider,
+        root_dir: str = None, custom_args: Dict = {}
+    ):
         # filesystems created with a block device stores the mountpoint
         # here. The file name of the file containing the filesystem is
         # stored in the device_provider if the filesystem is represented
         # as a file there
-        self.filesystem_mount = None
+        self.filesystem_mount: Optional[MountManager] = None
 
         # bind the block device providing class instance to this object.
         # This is done to guarantee the correct destructor order when
@@ -62,10 +69,10 @@ class FileSystemBase:
         # filesystem file name here
         self.filename = None
 
-        self.custom_args = {}
+        self.custom_args: Dict = {}
         self.post_init(custom_args)
 
-    def post_init(self, custom_args):
+    def post_init(self, custom_args: Dict):
         """
         Post initialization method
 
@@ -99,7 +106,7 @@ class FileSystemBase:
         if not self.custom_args.get('fs_attributes'):
             self.custom_args['fs_attributes'] = []
 
-    def create_on_device(self, label=None):
+    def create_on_device(self, label: str = None):
         """
         Create filesystem on block device
 
@@ -110,7 +117,9 @@ class FileSystemBase:
         """
         raise NotImplementedError
 
-    def create_on_file(self, filename, label=None, exclude=None):
+    def create_on_file(
+        self, filename: str, label: str = None, exclude: List[str] = None
+    ):
         """
         Create filesystem from root data tree
 
@@ -123,7 +132,7 @@ class FileSystemBase:
         """
         raise NotImplementedError
 
-    def get_mountpoint(self):
+    def get_mountpoint(self) -> Optional[str]:
         """
         Provides mount point directory
 
@@ -135,8 +144,9 @@ class FileSystemBase:
         """
         if self.filesystem_mount:
             return self.filesystem_mount.mountpoint
+        return None
 
-    def sync_data(self, exclude=None):
+    def sync_data(self, exclude: List[str] = None):
         """
         Copy root data tree into filesystem
 
