@@ -55,10 +55,9 @@ class PackageManager(metaclass=ABCMeta):
         name_map = {
             'zypper': ['zypper', 'Zypper'],
             'dnf': ['dnf', 'Dnf'],
-            'yum': ['dnf', 'Dnf'],
             'microdnf': ['microdnf', 'MicroDnf'],
             'pacman': ['pacman', 'Pacman'],
-            'apt-get': ['apt', 'Apt']
+            'apt': ['apt', 'Apt']
         }
         try:
             (module_namespace, module_name) = name_map[package_manager_name]
