@@ -19,6 +19,7 @@ import os
 import glob
 from configparser import ConfigParser
 from tempfile import NamedTemporaryFile
+from typing import List, Dict
 
 # project
 from kiwi.defaults import Defaults
@@ -38,7 +39,8 @@ class RepositoryDnf(RepositoryBase):
     :param dict command_env: customized os.environ for dnf
     :param str runtime_dnf_config: instance of :class:`ConfigParser`
     """
-    def post_init(self, custom_args=None):
+
+    def post_init(self, custom_args: List = []) -> None:
         """
         Post initialization method
 
@@ -49,8 +51,6 @@ class RepositoryDnf(RepositoryBase):
         """
         self.custom_args = custom_args
         self.exclude_docs = False
-        if not custom_args:
-            self.custom_args = []
 
         # extract custom arguments not used in dnf call
         if 'exclude_docs' in self.custom_args:
@@ -69,7 +69,7 @@ class RepositoryDnf(RepositoryBase):
         if self.locale:
             self.custom_args.remove(self.locale[0])
 
-        self.repo_names = []
+        self.repo_names: List = []
 
         # dnf support is based on creating repo files which contains
         # path names to the repo and its cache. In order to allow a
@@ -100,7 +100,7 @@ class RepositoryDnf(RepositoryBase):
         self._create_runtime_plugin_config_parser()
         self._write_runtime_config()
 
-    def setup_package_database_configuration(self):
+    def setup_package_database_configuration(self) -> None:
         """
         Setup rpm macros for bootstrapping and image building
 
@@ -149,7 +149,7 @@ class RepositoryDnf(RepositoryBase):
                 ], raise_on_error=False
             )
 
-    def use_default_location(self):
+    def use_default_location(self) -> None:
         """
         Setup dnf repository operations to store all data
         in the default places
@@ -166,7 +166,7 @@ class RepositoryDnf(RepositoryBase):
         self._create_runtime_plugin_config_parser()
         self._write_runtime_config()
 
-    def runtime_config(self):
+    def runtime_config(self) -> Dict:
         """
         dnf runtime configuration and environment
 
@@ -180,18 +180,18 @@ class RepositoryDnf(RepositoryBase):
         }
 
     def add_repo(
-        self, name, uri, repo_type='rpm-md',
-        prio=None, dist=None, components=None,
-        user=None, secret=None, credentials_file=None,
-        repo_gpgcheck=None, pkg_gpgcheck=None,
-        sourcetype=None, use_for_bootstrap=False
-    ):
+        self, name: str, uri: str, repo_type: str = 'rpm-md',
+        prio: int = None, dist: str = None, components: str = None,
+        user: str = None, secret: str = None, credentials_file: str = None,
+        repo_gpgcheck: bool = False, pkg_gpgcheck: bool = False,
+        sourcetype: str = None, use_for_bootstrap: bool = False
+    ) -> None:
         """
         Add dnf repository
 
         :param str name: repository base file name
         :param str uri: repository URI
-        :param repo_type: repostory type name
+        :param str repo_type: repostory type name
         :param int prio: dnf repostory priority
         :param str dist: unused
         :param str components: unused
@@ -221,25 +221,24 @@ class RepositoryDnf(RepositoryBase):
             repo_config.set(
                 name, 'priority', format(prio)
             )
-        if repo_gpgcheck is not None:
-            repo_config.set(
-                name, 'repo_gpgcheck', '1' if repo_gpgcheck else '0'
-            )
-        if pkg_gpgcheck is not None:
-            repo_config.set(
-                name, 'gpgcheck', '1' if pkg_gpgcheck else '0'
-            )
+        repo_config.set(
+            name, 'repo_gpgcheck', '1' if repo_gpgcheck else '0'
+        )
+        repo_config.set(
+            name, 'gpgcheck', '1' if pkg_gpgcheck else '0'
+        )
         if Defaults.is_buildservice_worker():
-            # when building in the build service, modular metadata is inaccessible...
-            # in order to use modular content in the build service, we need to disable
-            # modular filtering, which is done with module_hotfixes option
+            # when building in the build service, modular metadata is
+            # inaccessible. In order to use modular content in the build
+            # service, we need to disable modular filtering, which is
+            # done with module_hotfixes option
             repo_config.set(
                 name, 'module_hotfixes', '1'
             )
         with open(repo_file, 'w') as repo:
             repo_config.write(repo)
 
-    def import_trusted_keys(self, signing_keys):
+    def import_trusted_keys(self, signing_keys: List) -> None:
         """
         Imports trusted keys into the image
 
@@ -249,7 +248,7 @@ class RepositoryDnf(RepositoryBase):
         for key in signing_keys:
             rpmdb.import_signing_key_to_image(key)
 
-    def delete_repo(self, name):
+    def delete_repo(self, name: str) -> None:
         """
         Delete dnf repository
 
@@ -259,14 +258,14 @@ class RepositoryDnf(RepositoryBase):
             self.shared_dnf_dir['reposd-dir'] + '/' + name + '.repo'
         )
 
-    def delete_all_repos(self):
+    def delete_all_repos(self) -> None:
         """
         Delete all dnf repositories
         """
         Path.wipe(self.shared_dnf_dir['reposd-dir'])
         Path.create(self.shared_dnf_dir['reposd-dir'])
 
-    def delete_repo_cache(self, name):
+    def delete_repo_cache(self, name: str) -> None:
         """
         Delete dnf repository cache
 
@@ -284,7 +283,7 @@ class RepositoryDnf(RepositoryBase):
         for dnf_cache_file in glob.iglob(dnf_cache_glob_pattern):
             Path.wipe(dnf_cache_file)
 
-    def cleanup_unused_repos(self):
+    def cleanup_unused_repos(self) -> None:
         """
         Delete unused dnf repositories
 
@@ -298,14 +297,14 @@ class RepositoryDnf(RepositoryBase):
             if repo_file not in self.repo_names:
                 Path.wipe(repos_dir + '/' + repo_file)
 
-    def _create_dnf_runtime_environment(self):
+    def _create_dnf_runtime_environment(self) -> Dict:
         for dnf_dir in list(self.shared_dnf_dir.values()):
             Path.create(dnf_dir)
         return dict(
             os.environ, LANG='C'
         )
 
-    def _create_runtime_config_parser(self):
+    def _create_runtime_config_parser(self) -> None:
         self.runtime_dnf_config = ConfigParser()
         self.runtime_dnf_config.add_section('main')
 
@@ -344,7 +343,7 @@ class RepositoryDnf(RepositoryBase):
                 'main', 'tsflags', 'nodocs'
             )
 
-    def _create_runtime_plugin_config_parser(self):
+    def _create_runtime_plugin_config_parser(self) -> None:
         self.runtime_dnf_plugin_config = ConfigParser()
         self.runtime_dnf_plugin_config.add_section('main')
 
@@ -352,7 +351,7 @@ class RepositoryDnf(RepositoryBase):
             'main', 'enabled', '1'
         )
 
-    def _write_runtime_config(self):
+    def _write_runtime_config(self) -> None:
         with open(self.runtime_dnf_config_file.name, 'w') as config:
             self.runtime_dnf_config.write(config)
         if os.path.exists(self.shared_dnf_dir['pluginconf-dir']):
