@@ -11,6 +11,7 @@ from collections import OrderedDict
 from collections import namedtuple
 from builtins import bytes
 
+from kiwi.defaults import Defaults
 from kiwi.xml_description import XMLDescription
 from kiwi.xml_state import XMLState
 from kiwi.builder.disk import DiskBuilder
@@ -25,9 +26,8 @@ from kiwi.exceptions import (
 
 class TestDiskBuilder:
     @patch('os.path.exists')
-    @patch('platform.machine')
-    def setup(self, mock_machine, mock_exists):
-        mock_machine.return_value = 'x86_64'
+    def setup(self, mock_exists):
+        Defaults.set_platform_name('x86_64')
 
         def side_effect(filename):
             if filename.endswith('.config/kiwi/config.yml'):
@@ -195,9 +195,8 @@ class TestDiskBuilder:
     def teardown(self):
         sys.argv = argv_kiwi_tests
 
-    @patch('platform.machine')
-    def test_setup_ix86(self, mock_machine):
-        mock_machine.return_value = 'i686'
+    def test_setup_ix86(self):
+        Defaults.set_platform_name('i686')
         description = XMLDescription(
             '../data/example_disk_config.xml'
         )
@@ -297,7 +296,7 @@ class TestDiskBuilder:
             self.disk_setup.boot_partition_size()
         )
         self.disk.create_swap_partition.assert_called_once_with(
-            128
+            '128'
         )
         self.disk.create_prep_partition.assert_called_once_with(
             self.firmware.get_prep_partition_size()
@@ -310,7 +309,7 @@ class TestDiskBuilder:
             '0815'
         )
         self.bootloader_config.write_meta_data.assert_called_once_with(
-            boot_options='', root_uuid='0815'
+            root_device='/dev/root-device', boot_options=''
         )
         self.bootloader_config.setup_disk_image_config.assert_called_once_with(
             boot_options={
@@ -352,8 +351,9 @@ class TestDiskBuilder:
         call = filesystem.sync_data.call_args_list[2]
         assert filesystem.sync_data.call_args_list[2] == \
             call([
-                'image', '.profile', '.kconfig', '.buildenv', 'var/cache/kiwi',
-                'boot/*', 'boot/.*', 'boot/efi/*', 'boot/efi/.*'
+                'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
+                '.buildenv', 'var/cache/kiwi', 'boot/*', 'boot/.*',
+                'boot/efi/*', 'boot/efi/.*'
             ])
         assert m_open.call_args_list[0:4] == [
             call('boot_dir/config.partids', 'w'),
@@ -437,7 +437,7 @@ class TestDiskBuilder:
             '0815'
         )
         self.bootloader_config.write_meta_data.assert_called_once_with(
-            boot_options='', root_uuid='0815'
+            root_device='/dev/root-device', boot_options=''
         )
         self.bootloader_config.setup_disk_image_config.assert_called_once_with(
             boot_options={
@@ -480,8 +480,9 @@ class TestDiskBuilder:
         call = filesystem.sync_data.call_args_list[2]
         assert filesystem.sync_data.call_args_list[2] == \
             call([
-                'image', '.profile', '.kconfig', '.buildenv', 'var/cache/kiwi',
-                'boot/*', 'boot/.*', 'boot/efi/*', 'boot/efi/.*'
+                'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
+                '.buildenv', 'var/cache/kiwi', 'boot/*', 'boot/.*',
+                'boot/efi/*', 'boot/efi/.*'
             ])
         assert m_open.call_args_list == [
             call('boot_dir/config.partids', 'w'),
@@ -520,6 +521,7 @@ class TestDiskBuilder:
         assert self.boot_image_task.write_system_config_file.call_args_list == \
             []
 
+    @patch('kiwi.builder.disk.DeviceProvider')
     @patch('kiwi.builder.disk.FileSystem.new')
     @patch('kiwi.builder.disk.FileSystemSquashFs')
     @patch('kiwi.builder.disk.Command.run')
@@ -530,7 +532,8 @@ class TestDiskBuilder:
     @patch('random.randrange')
     def test_create_disk_standard_root_is_overlay(
         self, mock_rand, mock_temp, mock_getsize, mock_exists,
-        mock_grub_dir, mock_command, mock_squashfs, mock_fs
+        mock_grub_dir, mock_command, mock_squashfs, mock_fs,
+        mock_DeviceProvider
     ):
         mock_rand.return_value = 15
         self.disk_builder.root_filesystem_is_overlay = True
@@ -551,16 +554,19 @@ class TestDiskBuilder:
         assert mock_squashfs.call_args_list == [
             call(
                 custom_args={'compression': None},
-                device_provider=None, root_dir='root_dir'
+                device_provider=mock_DeviceProvider.return_value,
+                root_dir='root_dir'
             ), call(
                 custom_args={'compression': None},
-                device_provider=None, root_dir='root_dir'
+                device_provider=mock_DeviceProvider.return_value,
+                root_dir='root_dir'
             )
         ]
         assert squashfs.create_on_file.call_args_list == [
             call(exclude=['var/cache/kiwi'], filename='tempname'),
             call(exclude=[
-                'image', '.profile', '.kconfig', '.buildenv', 'var/cache/kiwi',
+                'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
+                '.buildenv', 'var/cache/kiwi',
                 'boot/*', 'boot/.*', 'boot/efi/*', 'boot/efi/.*'
             ], filename='tempname')
         ]
@@ -753,7 +759,8 @@ class TestDiskBuilder:
         ]
         volume_manager.sync_data.assert_called_once_with(
             [
-                'image', '.profile', '.kconfig', '.buildenv', 'var/cache/kiwi',
+                'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
+                '.buildenv', 'var/cache/kiwi',
                 'boot/*', 'boot/.*', 'boot/efi/*', 'boot/efi/.*'
             ]
         )
@@ -835,7 +842,7 @@ class TestDiskBuilder:
         with patch('builtins.open'):
             self.disk_builder.create_disk()
 
-        self.disk.create_spare_partition.assert_called_once_with(42)
+        self.disk.create_spare_partition.assert_called_once_with('42')
         assert mock_fs.call_args_list[0] == call(
             self.disk_builder.spare_part_fs,
             self.device_map['spare'],
@@ -844,8 +851,8 @@ class TestDiskBuilder:
         )
         assert filesystem.sync_data.call_args_list.pop() == call(
             [
-                'image', '.profile', '.kconfig', '.buildenv',
-                'var/cache/kiwi', 'var/*', 'var/.*',
+                'image', '.profile', '.kconfig', 'run/*', 'tmp/*',
+                '.buildenv', 'var/cache/kiwi', 'var/*', 'var/.*',
                 'boot/*', 'boot/.*', 'boot/efi/*', 'boot/efi/.*'
             ]
         )
