@@ -7,17 +7,17 @@ import kiwi
 
 from collections import namedtuple
 
+from kiwi.defaults import Defaults
 from kiwi.builder.install import InstallImageBuilder
 from kiwi.exceptions import KiwiInstallBootImageError
 
 
 class TestInstallImageBuilder:
-    @patch('platform.machine')
-    def setup(self, mock_machine):
+    def setup(self):
+        Defaults.set_platform_name('x86_64')
         boot_names_type = namedtuple(
             'boot_names_type', ['kernel_name', 'initrd_name']
         )
-        mock_machine.return_value = 'x86_64'
         self.setup = mock.Mock()
         kiwi.builder.install.SystemSetup = mock.Mock(
             return_value=self.setup
@@ -92,9 +92,8 @@ class TestInstallImageBuilder:
             self.xml_state, 'root_dir', 'target_dir', self.boot_image_task
         )
 
-    @patch('platform.machine')
-    def test_setup_ix86(self, mock_machine):
-        mock_machine.return_value = 'i686'
+    def test_setup_ix86(self):
+        Defaults.set_platform_name('i686')
         xml_state = mock.Mock()
         xml_state.xml_data.get_name = mock.Mock(
             return_value='result-image'
@@ -113,6 +112,7 @@ class TestInstallImageBuilder:
         )
         assert install_image.arch == 'ix86'
 
+    @patch('kiwi.builder.install.DeviceProvider')
     @patch('kiwi.builder.install.BootLoaderConfig.new')
     @patch('kiwi.builder.install.IsoToolsBase.setup_media_loader_directory')
     @patch('kiwi.builder.install.shutil.copy')
@@ -121,7 +121,8 @@ class TestInstallImageBuilder:
     @patch('kiwi.builder.install.Defaults.get_grub_boot_directory_name')
     def test_create_install_iso(
         self, mock_grub_dir, mock_command, mock_dtemp, mock_copy,
-        mock_setup_media_loader_directory, mock_BootLoaderConfig
+        mock_setup_media_loader_directory, mock_BootLoaderConfig,
+        mock_DeviceProvider
     ):
         tmpdir_name = ['temp-squashfs', 'temp_media_dir']
 
@@ -155,7 +156,8 @@ class TestInstallImageBuilder:
         ]
         kiwi.builder.install.FileSystemSquashFs.assert_called_once_with(
             custom_args={'compression': mock.ANY},
-            device_provider=None, root_dir='temp-squashfs'
+            device_provider=mock_DeviceProvider.return_value,
+            root_dir='temp-squashfs'
         )
         self.squashed_image.create_on_file.assert_called_once_with(
             'target_dir/result-image.raw.squashfs'
