@@ -8,14 +8,14 @@ import kiwi
 
 from ..test_helper import argv_kiwi_tests
 
+from kiwi.defaults import Defaults
 from kiwi.builder.live import LiveImageBuilder
 from kiwi.exceptions import KiwiLiveBootImageError
 
 
 class TestLiveImageBuilder:
-    @patch('platform.machine')
-    def setup(self, mock_machine):
-        mock_machine.return_value = 'x86_64'
+    def setup(self):
+        Defaults.set_platform_name('x86_64')
 
         self.firmware = mock.Mock()
         self.firmware.efi_mode = mock.Mock(
@@ -114,8 +114,8 @@ class TestLiveImageBuilder:
     def teardown(self):
         sys.argv = argv_kiwi_tests
 
-    @patch('platform.machine')
-    def test_init_for_ix86_platform(self, mock_machine):
+    def test_init_for_ix86_platform(self):
+        Defaults.set_platform_name('i686')
         xml_state = mock.Mock()
         xml_state.xml_data.get_name = mock.Mock(
             return_value='some-image'
@@ -123,12 +123,12 @@ class TestLiveImageBuilder:
         xml_state.get_image_version = mock.Mock(
             return_value='1.2.3'
         )
-        mock_machine.return_value = 'i686'
         live_image = LiveImageBuilder(
             xml_state, 'target_dir', 'root_dir'
         )
         assert live_image.arch == 'ix86'
 
+    @patch('kiwi.builder.live.DeviceProvider')
     @patch('kiwi.builder.live.IsoToolsBase.setup_media_loader_directory')
     @patch('kiwi.builder.live.mkdtemp')
     @patch('kiwi.builder.live.NamedTemporaryFile')
@@ -142,7 +142,7 @@ class TestLiveImageBuilder:
     def test_create_overlay_structure(
         self, mock_exists, mock_grub_dir, mock_size, mock_filesystem,
         mock_isofs, mock_tag, mock_shutil, mock_tmpfile, mock_dtemp,
-        mock_setup_media_loader_directory
+        mock_setup_media_loader_directory, mock_DeviceProvider
     ):
         tempfile = mock.Mock()
         tempfile.name = 'tmpfile'
@@ -188,16 +188,18 @@ class TestLiveImageBuilder:
                 }
             ),
             call(
-                device_provider=None, name='squashfs',
+                device_provider=mock_DeviceProvider.return_value,
+                name='squashfs',
                 root_dir='temp-squashfs',
                 custom_args={'compression': 'lzo'}
             )
         ]
 
         filesystem.create_on_device.assert_called_once_with()
-        filesystem.sync_data.assert_called_once_with(
-            ['image', '.profile', '.kconfig', '.buildenv', 'var/cache/kiwi']
-        )
+        filesystem.sync_data.assert_called_once_with([
+            'image', '.profile', '.kconfig',
+            'run/*', 'tmp/*', '.buildenv', 'var/cache/kiwi'
+        ])
         filesystem.create_on_file.assert_called_once_with('tmpfile')
 
         assert mock_shutil.copy.call_args_list == [
@@ -268,7 +270,9 @@ class TestLiveImageBuilder:
                     'efi_mode': 'uefi',
                     'udf': True
                 }
-            }, device_provider=None, root_dir='temp_media_dir'
+            },
+            device_provider=mock_DeviceProvider.return_value,
+            root_dir='temp_media_dir'
         )
         iso_image.create_on_file.assert_called_once_with(
             'target_dir/result-image.x86_64-1.2.3.iso'
