@@ -8,6 +8,8 @@ from pytest import (
 from .test_helper import argv_kiwi_tests
 
 from kiwi.cli import Cli
+from kiwi.defaults import Defaults
+
 from kiwi.exceptions import (
     KiwiCompatError,
     KiwiLoadCommandUndefined,
@@ -22,7 +24,7 @@ class TestCli:
         self._caplog = caplog
 
     def setup(self):
-        self.help_global_args = {
+        self.expected_global_args = {
             'help': False,
             '--compat': False,
             'compat': False,
@@ -38,7 +40,9 @@ class TestCli:
             'result': False,
             '--profile': [],
             '--shared-cache-dir': '/var/cache/kiwi',
-            '--help': False
+            '--target-arch': None,
+            '--help': False,
+            '--config': 'config-file'
         }
         self.command_args = {
             '--add-repo': [],
@@ -114,6 +118,17 @@ class TestCli:
             assert 'vmx type is now a subset of oem, --type set to oem' in \
                 self._caplog.text
 
+    def test_set_target_arch(self):
+        sys.argv = [
+            sys.argv[0],
+            '--target-arch', 'artificial', 'system', 'build',
+            '--description', 'description',
+            '--target-dir', 'directory'
+        ]
+        cli = Cli()
+        cli.get_global_args()
+        assert Defaults.get_platform_name() == 'artificial'
+
     def test_get_servicename_image(self):
         sys.argv = [
             sys.argv[0],
@@ -140,7 +155,16 @@ class TestCli:
         assert self.cli.get_command_args() == self.command_args
 
     def test_get_global_args(self):
-        assert self.cli.get_global_args() == self.help_global_args
+        self.cli.all_args['--config'] = 'config-file'
+        sys.argv = [
+            sys.argv[0],
+            '--config', 'config-file',
+            'system', 'build',
+            '--description', 'description',
+            '--target-dir', 'directory'
+        ]
+        cli = Cli()
+        assert cli.get_global_args() == self.expected_global_args
 
     def test_load_command(self):
         assert self.cli.load_command() == self.loaded_command
