@@ -36,11 +36,13 @@ class TestContainerImageAppx:
     @patch('kiwi.container.appx.ArchiveTar')
     @patch('kiwi.container.appx.Compress')
     @patch('kiwi.container.appx.Defaults.get_exclude_list_for_root_data_sync')
+    @patch('kiwi.container.appx.Defaults.get_exclude_list_from_custom_exclude_files')
     @patch('kiwi.container.appx.NamedTemporaryFile')
     @patch('kiwi.container.appx.Command.run')
     @patch('os.walk')
     def test_create(
         self, mock_os_walk, mock_Command_run, mock_NamedTemporaryFile,
+        mock_get_exclude_list_from_custom_exclude_files,
         mock_get_exclude_list_for_root_data_sync,
         mock_Compress, mock_ArchiveTar
     ):
@@ -67,7 +69,9 @@ class TestContainerImageAppx:
         mock_ArchiveTar.assert_called_once_with('meta/data/install.tar')
         archive.create.assert_called_once_with(
             'root_dir',
-            exclude=mock_get_exclude_list_for_root_data_sync.return_value
+            exclude=mock_get_exclude_list_for_root_data_sync.
+            return_value + mock_get_exclude_list_from_custom_exclude_files.
+            return_value
         )
         mock_Compress.assert_called_once_with(
             archive.create.return_value
