@@ -1,8 +1,9 @@
+import logging
 from mock import patch
 
 import sys
-
 import mock
+from pytest import fixture
 
 from .test_helper import argv_kiwi_tests
 
@@ -10,6 +11,10 @@ from kiwi.defaults import Defaults
 
 
 class TestDefaults:
+    @fixture(autouse=True)
+    def inject_fixtures(self, caplog):
+        self._caplog = caplog
+
     def setup(self):
         self.defaults = Defaults()
 
@@ -36,7 +41,8 @@ class TestDefaults:
         )
 
     def test_get_preparer(self):
-        assert Defaults.get_preparer() == 'KIWI - https://github.com/OSInside/kiwi'
+        assert Defaults.get_preparer() == \
+            'KIWI - https://github.com/OSInside/kiwi'
 
     def test_get_publisher(self):
         assert Defaults.get_publisher() == 'SUSE LINUX GmbH'
@@ -63,11 +69,10 @@ class TestDefaults:
         assert Defaults.get_live_dracut_modules_from_flag('dmsquash') == \
             ['dmsquash-live', 'livenet']
 
-    @patch('platform.machine')
-    def test_get_iso_boot_path(self, mock_machine):
-        mock_machine.return_value = 'i686'
+    def test_get_iso_boot_path(self):
+        Defaults.set_platform_name('i686')
         assert Defaults.get_iso_boot_path() == 'boot/ix86'
-        mock_machine.return_value = 'x86_64'
+        Defaults.set_platform_name('x86_64')
         assert Defaults.get_iso_boot_path() == 'boot/x86_64'
 
     @patch('kiwi.defaults.glob.iglob')
@@ -86,3 +91,22 @@ class TestDefaults:
         mock_path_exists.return_value = True
         assert Defaults.get_vendor_grubenv('boot/efi') == \
             'boot/efi/EFI/fedora/grubenv'
+
+    def test_get_exclude_list_from_custom_exclude_files(self):
+        assert Defaults.get_exclude_list_from_custom_exclude_files(
+            '../data/root-dir'
+        ) == [
+            'usr/bin/qemu-binfmt',
+            'usr/bin/qemu-x86_64-binfmt',
+            'usr/bin/qemu-x86_64'
+        ]
+
+    @patch('yaml.safe_load')
+    def test_get_exclude_list_from_custom_exclude_files_is_invalid(
+        self, mock_yaml_safe_load
+    ):
+        mock_yaml_safe_load.return_value = {'invalid': 'artificial'}
+        with self._caplog.at_level(logging.WARNING):
+            assert Defaults.get_exclude_list_from_custom_exclude_files(
+                '../data/root-dir'
+            ) == []
