@@ -1,10 +1,14 @@
 import sys
-from mock import patch
-import mock
+from mock import (
+    patch, Mock
+)
 from pytest import raises
 
 from .test_helper import argv_kiwi_tests
 
+import kiwi
+
+from kiwi.defaults import Defaults
 from kiwi.xml_state import XMLState
 from kiwi.xml_description import XMLDescription
 from kiwi.runtime_checker import RuntimeChecker
@@ -19,9 +23,18 @@ class TestRuntimeChecker:
         self.xml_state = XMLState(
             self.description.load()
         )
+        self.runtime_config = Mock()
+        self.runtime_config.get_oci_archive_tool.return_value = 'umoci'
+        kiwi.runtime_checker.RuntimeConfig = Mock(
+            return_value=self.runtime_config
+        )
         self.runtime_checker = RuntimeChecker(self.xml_state)
 
-    def test_check_image_include_repos_publicly_resolvable(self):
+    @patch('kiwi.runtime_checker.Uri')
+    def test_check_image_include_repos_publicly_resolvable(self, mock_Uri):
+        uri = Mock()
+        uri.is_public.return_value = False
+        mock_Uri.return_value = uri
         with raises(KiwiRuntimeError):
             self.runtime_checker.check_image_include_repos_publicly_resolvable()
 
@@ -51,6 +64,56 @@ class TestRuntimeChecker:
                 '//var/cache//kiwi/foo'
             )
 
+    @patch('os.path.isdir')
+    def test_check_dracut_module_versions_compatible_to_kiwi_no_dracut(
+        self, mock_os_path_isdir
+    ):
+        mock_os_path_isdir.return_value = False
+        self.runtime_checker.\
+            check_dracut_module_versions_compatible_to_kiwi('root_dir')
+        # does not raise if no dracut is installed
+
+    @patch('os.listdir')
+    @patch('os.path.isdir')
+    @patch('kiwi.runtime_checker.Command.run')
+    def test_check_dracut_module_versions_compatible_to_kiwi(
+        self, mock_Command_run, mock_os_path_isdir, mock_os_listdir
+    ):
+        mock_os_path_isdir.return_value = True
+        command = Mock()
+        command.output = '1.2.3-1.2'
+        mock_Command_run.return_value = command
+        mock_os_listdir.return_value = ['90kiwi-dump']
+        package_manager = Mock()
+        package_manager.return_value = 'zypper'
+        self.xml_state.get_package_manager = package_manager
+        with raises(KiwiRuntimeError) as exception_data:
+            self.runtime_checker.\
+                check_dracut_module_versions_compatible_to_kiwi('root_dir')
+        assert "'dracut-kiwi-oem-dump': 'got:1.2.3, need:>=9.20.1'" in str(
+            exception_data.value
+        )
+        mock_Command_run.assert_called_once_with(
+            [
+                'rpm', '--root', 'root_dir', '-q',
+                '--qf', '%{VERSION}', 'dracut-kiwi-oem-dump'
+            ]
+        )
+        package_manager.return_value = 'apt'
+        mock_Command_run.reset_mock()
+        with raises(KiwiRuntimeError) as exception_data:
+            self.runtime_checker.\
+                check_dracut_module_versions_compatible_to_kiwi('root_dir')
+        assert "'dracut-kiwi-oem-dump': 'got:1.2.3, need:>=9.20.1'" in str(
+            exception_data.value
+        )
+        mock_Command_run.assert_called_once_with(
+            [
+                'dpkg-query', '--admindir', 'root_dir/var/lib/dpkg',
+                '-W', '-f', '${Version}', 'dracut-kiwi-oem-dump'
+            ]
+        )
+
     def test_valid_target_dir_1(self):
         assert self.runtime_checker.check_target_directory_not_in_shared_cache(
             '/var/cache/kiwi-fast-tmpsystemdir'
@@ -109,12 +172,11 @@ class TestRuntimeChecker:
         with raises(KiwiRuntimeError):
             runtime_checker.check_container_tool_chain_installed()
 
-    @patch('kiwi.runtime_checker.RuntimeConfig.get_oci_archive_tool')
     @patch('kiwi.runtime_checker.Path.which')
     def test_check_container_tool_chain_installed_unknown_tool(
-        self, mock_which, mock_oci_tool
+        self, mock_which
     ):
-        mock_oci_tool.return_value = 'budah'
+        self.runtime_config.get_oci_archive_tool.return_value = 'budah'
         mock_which.return_value = False
         xml_state = XMLState(
             self.description.load(), ['docker'], 'docker'
@@ -123,12 +185,11 @@ class TestRuntimeChecker:
         with raises(KiwiRuntimeError):
             runtime_checker.check_container_tool_chain_installed()
 
-    @patch('kiwi.runtime_checker.RuntimeConfig.get_oci_archive_tool')
     @patch('kiwi.runtime_checker.Path.which')
     def test_check_container_tool_chain_installed_buildah(
-        self, mock_which, mock_oci_tool
+        self, mock_which
     ):
-        mock_oci_tool.return_value = 'buildah'
+        self.runtime_config.get_oci_archive_tool.return_value = 'buildah'
         mock_which.return_value = False
         xml_state = XMLState(
             self.description.load(), ['docker'], 'docker'
@@ -167,13 +228,12 @@ class TestRuntimeChecker:
         with raises(KiwiRuntimeError):
             runtime_checker.check_container_tool_chain_installed()
 
-    @patch('platform.machine')
     @patch('kiwi.runtime_checker.Defaults.get_boot_image_description_path')
     def test_check_consistent_kernel_in_boot_and_system_image(
-        self, mock_boot_path, mock_machine
+        self, mock_boot_path
     ):
+        Defaults.set_platform_name('x86_64')
         mock_boot_path.return_value = '../data'
-        mock_machine.return_value = 'x86_64'
         xml_state = XMLState(
             self.description.load(), ['vmxFlavour'], 'oem'
         )
@@ -209,26 +269,26 @@ class TestRuntimeChecker:
             runtime_checker.check_boot_description_exists()
 
     def test_check_xen_uniquely_setup_as_server_or_guest_for_ec2(self):
-        self.xml_state.build_type.get_firmware = mock.Mock(
+        self.xml_state.build_type.get_firmware = Mock(
             return_value='ec2'
         )
-        self.xml_state.is_xen_server = mock.Mock(
+        self.xml_state.is_xen_server = Mock(
             return_value=True
         )
-        self.xml_state.is_xen_guest = mock.Mock(
+        self.xml_state.is_xen_guest = Mock(
             return_value=True
         )
         with raises(KiwiRuntimeError):
             self.runtime_checker.check_xen_uniquely_setup_as_server_or_guest()
 
     def test_check_xen_uniquely_setup_as_server_or_guest_for_xen(self):
-        self.xml_state.build_type.get_firmware = mock.Mock(
+        self.xml_state.build_type.get_firmware = Mock(
             return_value=None
         )
-        self.xml_state.is_xen_server = mock.Mock(
+        self.xml_state.is_xen_server = Mock(
             return_value=True
         )
-        self.xml_state.is_xen_guest = mock.Mock(
+        self.xml_state.is_xen_guest = Mock(
             return_value=True
         )
         with raises(KiwiRuntimeError):
@@ -238,7 +298,7 @@ class TestRuntimeChecker:
         xml_state = XMLState(
             self.description.load(), ['vmxFlavour'], 'iso'
         )
-        xml_state.build_type.get_overlayroot = mock.Mock(
+        xml_state.build_type.get_overlayroot = Mock(
             return_value=True
         )
         runtime_checker = RuntimeChecker(xml_state)
@@ -247,10 +307,10 @@ class TestRuntimeChecker:
                 check_dracut_module_for_disk_overlay_in_package_list()
 
     def test_check_efi_mode_for_disk_overlay_correctly_setup(self):
-        self.xml_state.build_type.get_overlayroot = mock.Mock(
+        self.xml_state.build_type.get_overlayroot = Mock(
             return_value=True
         )
-        self.xml_state.build_type.get_firmware = mock.Mock(
+        self.xml_state.build_type.get_firmware = Mock(
             return_value='uefi'
         )
         with raises(KiwiRuntimeError):
@@ -312,11 +372,8 @@ class TestRuntimeChecker:
         with raises(KiwiRuntimeError):
             runtime_checker.check_image_version_provided()
 
-    @patch('platform.machine')
-    def test_check_architecture_supports_iso_firmware_setup(
-        self, mock_machine
-    ):
-        mock_machine.return_value = 'aarch64'
+    def test_check_architecture_supports_iso_firmware_setup(self):
+        Defaults.set_platform_name('aarch64')
         xml_state = XMLState(
             self.description.load(), ['vmxFlavour'], 'iso'
         )
@@ -330,13 +387,12 @@ class TestRuntimeChecker:
         with raises(KiwiRuntimeError):
             runtime_checker.check_architecture_supports_iso_firmware_setup()
 
-    @patch('platform.machine')
     @patch('kiwi.runtime_checker.Path.which')
     def test_check_syslinux_installed_if_isolinux_is_used(
-        self, mock_Path_which, mock_machine
+        self, mock_Path_which
     ):
+        Defaults.set_platform_name('x86_64')
         mock_Path_which.return_value = None
-        mock_machine.return_value = 'x86_64'
         xml_state = XMLState(
             self.description.load(), ['vmxFlavour'], 'iso'
         )
