@@ -3,8 +3,11 @@ from mock import (
 )
 from pytest import raises
 
+from kiwi.defaults import Defaults
 from kiwi.storage.subformat.ova import DiskFormatOva
 
+import kiwi
+
 from kiwi.exceptions import (
     KiwiCommandNotFound,
     KiwiFormatSetupError
@@ -12,8 +15,8 @@ from kiwi.exceptions import (
 
 
 class TestDiskFormatOva:
-    @patch('platform.machine')
-    def setup(self, mock_machine):
+    def setup(self):
+        Defaults.set_platform_name('x86_64')
         self.context_manager_mock = Mock()
         self.file_mock = Mock()
         self.enter_mock = Mock()
@@ -21,7 +24,6 @@ class TestDiskFormatOva:
         self.enter_mock.return_value = self.file_mock
         setattr(self.context_manager_mock, '__enter__', self.enter_mock)
         setattr(self.context_manager_mock, '__exit__', self.exit_mock)
-        mock_machine.return_value = 'x86_64'
         xml_data = Mock()
         xml_data.get_name = Mock(
             return_value='some-disk-image'
@@ -56,6 +58,12 @@ class TestDiskFormatOva:
             return_value='vmware'
         )
 
+        self.runtime_config = Mock()
+        self.runtime_config.get_bundle_compression.return_value = False
+        kiwi.storage.subformat.base.RuntimeConfig = Mock(
+            return_value=self.runtime_config
+        )
+
         self.disk_format = DiskFormatOva(
             self.xml_state, 'root_dir', 'target_dir'
         )
