@@ -28,15 +28,14 @@ class TestSystemSetup:
     def inject_fixtures(self, caplog):
         self._caplog = caplog
 
-    @patch('platform.machine')
     @patch('kiwi.system.setup.RuntimeConfig')
-    def setup(self, mock_RuntimeConfig, mock_machine):
+    def setup(self, mock_RuntimeConfig):
+        Defaults.set_platform_name('x86_64')
         self.runtime_config = Mock()
         self.runtime_config.get_package_changes = Mock(
             return_value=True
         )
         mock_RuntimeConfig.return_value = self.runtime_config
-        mock_machine.return_value = 'x86_64'
         self.xml_state = MagicMock()
         self.xml_state.get_package_manager = Mock(
             return_value='zypper'
@@ -74,9 +73,8 @@ class TestSystemSetup:
     def teardown(self):
         sys.argv = argv_kiwi_tests
 
-    @patch('platform.machine')
-    def test_setup_ix86(self, mock_machine):
-        mock_machine.return_value = 'i686'
+    def test_setup_ix86(self):
+        Defaults.set_platform_name('i686')
         setup = SystemSetup(
             MagicMock(), 'root_dir'
         )
@@ -129,6 +127,12 @@ class TestSystemSetup:
                     'root_dir/image/images.sh'
                 ]
             ),
+            call(
+                [
+                    'cp', '{0}/post_bootstrap.sh'.format(self.description_dir),
+                    'root_dir/image/post_bootstrap.sh'
+                ]
+            ),
             call(
                 [
                     'cp', Defaults.project_file('config/functions.sh'),
@@ -158,7 +162,7 @@ class TestSystemSetup:
         self, mock_path, mock_command, mock_create
     ):
         path_return_values = [
-            True, False, True, True, True, True, True, True
+            True, False, True, True, True, True, True, True, True
         ]
 
         def side_effect(arg):
@@ -201,6 +205,12 @@ class TestSystemSetup:
                     'root_dir/image/images.sh'
                 ]
             ),
+            call(
+                [
+                    'cp', '{0}/post_bootstrap.sh'.format(self.description_dir),
+                    'root_dir/image/post_bootstrap.sh'
+                ]
+            ),
             call(
                 [
                     'cp', Defaults.project_file('config/functions.sh'),
@@ -664,6 +674,37 @@ class TestSystemSetup:
             ['chroot', 'root_dir', 'image/config.sh'], {}
         )
 
+    @patch('kiwi.system.setup.Profile')
+    @patch('kiwi.command.Command.call')
+    @patch('kiwi.command_process.CommandProcess.poll_and_watch')
+    @patch('os.path.exists')
+    @patch('os.stat')
+    @patch('os.access')
+    @patch('copy.deepcopy')
+    def test_call_excutable_post_bootstrap_script(
+        self, mock_copy_deepcopy, mock_access, mock_stat, mock_os_path,
+        mock_watch, mock_command, mock_Profile
+    ):
+        mock_copy_deepcopy.return_value = {}
+        profile = Mock()
+        mock_Profile.return_value = profile
+        profile.get_settings.return_value = {}
+        result_type = namedtuple(
+            'result', ['stderr', 'returncode']
+        )
+        mock_result = result_type(stderr='stderr', returncode=0)
+        mock_os_path.return_value = True
+        mock_watch.return_value = mock_result
+
+        # pretend that the script is executable
+        mock_access.return_value = True
+        self.setup.call_post_bootstrap_script()
+
+        mock_copy_deepcopy.assert_called_once_with(os.environ)
+        mock_command.assert_called_once_with(
+            ['chroot', 'root_dir', 'image/post_bootstrap.sh'], {}
+        )
+
     @patch('kiwi.system.setup.Profile')
     @patch('kiwi.command.Command.call')
     @patch('kiwi.command_process.CommandProcess.poll_and_watch')
@@ -958,19 +999,19 @@ class TestSystemSetup:
     def test_export_package_list_unknown_packager(
         self, mock_get_default_packager_tool
     ):
-        assert self.setup.export_package_list('target_dir') is None
+        assert self.setup.export_package_list('target_dir') == ''
 
     @patch('kiwi.defaults.Defaults.get_default_packager_tool')
     def test_export_package_changes_unknown_packager(
         self, mock_get_default_packager_tool
     ):
-        assert self.setup.export_package_changes('target_dir') is None
+        assert self.setup.export_package_changes('target_dir') == ''
 
     @patch('kiwi.defaults.Defaults.get_default_packager_tool')
     def test_export_package_verification_unknown_packager(
         self, mock_get_default_packager_tool
     ):
-        assert self.setup.export_package_verification('target_dir') is None
+        assert self.setup.export_package_verification('target_dir') == ''
 
     @patch('kiwi.system.setup.Command.run')
     @patch('kiwi.system.setup.RpmDataBase')
@@ -1053,7 +1094,7 @@ class TestSystemSetup:
         command.output = 'packages_data'
         mock_command.return_value = command
         self.xml_state.get_package_manager = Mock(
-            return_value='apt-get'
+            return_value='apt'
         )
 
         with patch('builtins.open') as m_open:
@@ -1131,7 +1172,7 @@ class TestSystemSetup:
         command.output = 'changes'
         mock_command.return_value = command
         self.xml_state.get_package_manager = Mock(
-            return_value='apt-get'
+            return_value='apt'
         )
         mock_os_listdir.return_value = ['package_b', 'package_a']
         mock_os_path_exists.return_value = True
@@ -1220,7 +1261,7 @@ class TestSystemSetup:
         command.output = 'verification_data'
         mock_command.return_value = command
         self.xml_state.get_package_manager = Mock(
-            return_value='apt-get'
+            return_value='apt'
         )
 
         with patch('builtins.open') as m_open:
