@@ -128,6 +128,11 @@ class TestSystemBuildTask:
         self.runtime_checker.\
             check_target_directory_not_in_shared_cache.\
             assert_called_once_with(self.abs_target_dir)
+        self.runtime_checker.\
+            check_dracut_module_versions_compatible_to_kiwi.\
+            assert_called_once_with(
+                self.abs_target_dir + '/build/image-root'
+            )
         self.runtime_checker.\
             check_mediacheck_installed.assert_called_once_with()
         self.runtime_checker.\
@@ -166,6 +171,7 @@ class TestSystemBuildTask:
         self.setup.import_overlay_files.assert_called_once_with()
         self.setup.import_repositories_marked_as_imageinclude.\
             assert_called_once_with()
+        self.setup.call_post_bootstrap_script.assert_called_once_with()
         self.setup.call_config_script.assert_called_once_with()
         self.setup.import_image_identifier.assert_called_once_with()
         self.setup.setup_groups.assert_called_once_with()
